/**
 * Copyright 2010 Västra Götalandsregionen
 *
 *   This library is free software; you can redistribute it and/or modify
 *   it under the terms of version 2.1 of the GNU Lesser General Public
 *   License as published by the Free Software Foundation.
 *
 *   This library is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU Lesser General Public License for more details.
 *
 *   You should have received a copy of the GNU Lesser General Public
 *   License along with this library; if not, write to the
 *   Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 *   Boston, MA 02111-1307  USA
 */

package se.vgregion.web.exceptions;

import org.springframework.http.HttpStatus;
import org.springframework.web.bind.annotation.ResponseStatus;

/**
 * Thrown to indicate that a method has been passed an illegal or inappropriate argument. If thrown from a servlet
 * or web service the response status code is set to BAD REQUEST(400).
 * 
 * @author Anders Asplund - <a href="http://www.callistaenterprise.se">Callista Enterprise</a>
 * 
 */
@ResponseStatus(value = HttpStatus.BAD_REQUEST, reason = "Ogiltigt argument")
public class IllegalWebArgumentException extends IllegalArgumentException {
    private static final long serialVersionUID = 1L;

    /**
     * Constructs a new {@link IllegalWebArgumentException}.
     */
    public IllegalWebArgumentException() {
        super();
    }

    /**
     * Constructs a new {@link IllegalWebArgumentException}.
     * 
     * @param message
     *            the detail message. The detail message is saved for later retrieval by the
     *            {@link Throwable#getMessage()} method.
     */
    public IllegalWebArgumentException(String message) {
        super(message);
    }

    /**
     * Constructs a new {@link IllegalWebArgumentException}.
     * 
     * @param cause
     *            the cause (which is saved for later retrieval by the {@link Throwable#getCause()} method). (A
     *            null value is permitted, and indicates that the cause is nonexistent or unknown.)
     */
    public IllegalWebArgumentException(Throwable cause) {
        super(cause);
    }

    /**
     * Constructs a new {@link IllegalWebArgumentException}.
     * 
     * @param message
     *            the detail message. The detail message is saved for later retrieval by the
     *            {@link Throwable#getMessage()} method.
     * @param cause
     *            the cause (which is saved for later retrieval by the {@link Throwable#getCause()} method). (A
     *            null value is permitted, and indicates that the cause is nonexistent or unknown.)
     */
    public IllegalWebArgumentException(String message, Throwable cause) {
        super(message, cause);
    }
}